@@ -1,3 +1,5 @@
+import argparse
+import os
 from argparse import RawTextHelpFormatter
 import sys
 from hhcp.cp_dir_multi import cp_dir
@@ -92,7 +94,7 @@ def load_config(args):
 def main():
     filelist, directory, destination, prefix, force = load_config(parse_args())
     if filelist is not None:
-        cp_list(filelist, destination, prefix, overwrite)
+        cp_list(filelist, destination, prefix, force)
     elif directory is not None:
         cp_dir(directory, destination, force)
     else:
